@@ -36,12 +36,14 @@ type BatchJobType string
 const (
 	BatchJobReplicate BatchJobType = "replicate"
 	BatchJobKeyRotate BatchJobType = "keyrotate"
+	BatchJobExpire    BatchJobType = "expire"
 )
 
 // SupportedJobTypes supported job types
 var SupportedJobTypes = []BatchJobType{
 	BatchJobReplicate,
 	BatchJobKeyRotate,
+	BatchJobExpire,
 	// add new job types
 }
 
@@ -94,7 +96,6 @@ const BatchJobReplicateTemplate = `replicate:
       #   - key: "name"
       #     value: "pick*" # match objects with tag 'name', with all values starting with 'pick'
 
-      ## NOTE: metadata filter not supported when "source" is non MinIO.
       # metadata:
       #   - key: "content-type"
       #     value: "image/*" # match objects with 'content-type', with all values starting with 'image/'
@@ -142,6 +143,47 @@ const BatchJobKeyRotateTemplate = `keyrotate:
       delay: "500ms" # least amount of delay between each retry
 `
 
+// BatchJobExpireTemplate provides a sample template
+// for batch expiring objects
+const BatchJobExpireTemplate = `expire:
+  apiVersion: v1
+  bucket: mybucket # Bucket where this job will expire matching objects from
+  prefix: myprefix # (Optional) Prefix under which this job will expire objects matching the rules below.
+  rules:
+    - type: object  # objects with zero ore more older versions
+      name: NAME # match object names that satisfy the wildcard expression.
+      olderThan: 70h # match objects older than this value
+      createdBefore: "2006-01-02T15:04:05.00Z" # match objects created before "date"
+      tags:
+        - key: name
+          value: pick* # match objects with tag 'name', all values starting with 'pick'
+      metadata:
+        - key: content-type
+          value: image/* # match objects with 'content-type', all values starting with 'image/'
+      size:
+        lesserThan: 10MiB # match objects with size lesser than this value (e.g. 10MiB)
+        greaterThan: 1MiB # match objects with size greater than this value (e.g. 1MiB)
+      purge:
+          # retainVersions: 0 # (default) delete all versions of the object. This option is the fastest.
+          # retainVersions: 5 # keep the latest 5 versions of the object.
+
+    - type: deleted # objects with delete marker as their latest version
+      name: NAME # match object names that satisfy the wildcard expression.
+      olderThan: 10h # match objects older than this value (e.g. 7d10h31s)
+      createdBefore: "2006-01-02T15:04:05.00Z" # match objects created before "date"
+      purge:
+          # retainVersions: 0 # (default) delete all versions of the object. This option is the fastest.
+          # retainVersions: 5 # keep the latest 5 versions of the object including delete markers.
+
+  notify:
+    endpoint: https://notify.endpoint # notification endpoint to receive job completion status
+    token: Bearer xxxxx # optional authentication token for the notification endpoint
+
+  retry:
+    attempts: 10 # number of retries for the job before giving up
+    delay: 500ms # least amount of delay between each retry
+`
+
 // BatchJobResult returned by StartBatchJob
 type BatchJobResult struct {
 	ID      string        `json:"id"`
@@ -211,14 +253,16 @@ type GenerateBatchJobOpts struct {
 // GenerateBatchJob creates a new job template from standard template
 // TODO: allow configuring yaml values
 func (adm *AdminClient) GenerateBatchJob(_ context.Context, opts GenerateBatchJobOpts) (string, error) {
+	// TODO: allow configuring the template to fill values from GenerateBatchJobOpts
 	switch opts.Type {
 	case BatchJobReplicate:
-		// TODO: allow configuring the template to fill values from GenerateBatchJobOpts
 		return BatchJobReplicateTemplate, nil
 	case BatchJobKeyRotate:
 		return BatchJobKeyRotateTemplate, nil
+	case BatchJobExpire:
+		return BatchJobExpireTemplate, nil
 	}
-	return "", fmt.Errorf("unsupported batch type requested: %s", opts.Type)
+	return "", fmt.Errorf("unknown batch job requested: %s", opts.Type)
 }
 
 // ListBatchJobsResult contains entries for all current jobs.
